==> HostCMS.Free_6.7.tar.gz: modules/benchmark/i18n/ru.php <==
<?php
/**
 * Benchmark.
 *
 * @package HostCMS
 * @subpackage Benchmark
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Оценка производительности',
	'menu' => 'Производительность',
	'menu_speed' => 'Быстродействие',
	'menu_rate' => 'Оценить производительность',
	'menu_site_speed' => 'Быстродействие сайта',
	'title' => 'Оценка производительности',
	'mbps' => '%s Мбит/с',
	'download_speed' => 'Скорость скачивания',
	'email' => 'Почтовая система',
	'email_val' => '%s сек.',
	'cpu_string' => 'Процессор, строки',
	'cpu_math' => 'Процессор, алгебра',
	'filesystem' => 'Файловая система',
	'bd_change' => 'БД, изменение',
	'bd_read' => 'БД, чтение',
	'bd_write' => 'БД, запись',
	'server' => 'Сервер',
	'etalon' => 'Эталон',
	'benchmark' => 'Общая оценка',
	'check_success' => 'Оценка производительности выполнена',
	'markDeleted_success' => 'Оценка производительности удалена',
	'waiting_time' => 'Ожидание ответа',
	'load_page_time' => 'Загрузка страницы',
	'dns_lookup' => 'Определение DNS',
	'connect_server' => 'Соединение с сервером',
	'start_monitoring' => 'Включить мониторинг быстродействия сайта',
	'reset' => 'Исходный вид',
	'benchmark_day' => 'Быстродействие по дням',
	'benchmark_hour' => 'Быстродействие по часам',

	'cache' => 'Кэширование',
	'cache_description' => 'Кэширует элементы страниц сайта с целью ускорения работы сайта, минимизации использования системных ресурсов в случае большой нагрузки на сервер.',

	'compression' => 'Компрессия страниц',
	'compression_description' => 'Компрессия ускоряет загрузку страниц сайта, сжимает передаваемые посетителям страницы сайта, объединяет Javascript и CSS-файлы.',
	'speedUp' => 'Повышение быстродействия',
	'database' => 'База данных',
	'tableEngines' => 'Типы таблиц в базе данных',
	'severalEnginesMsg' => 'В базе данных содержатся таблицы разных типов!',
	'changeStorageEnginesTitle' => 'Изменение системы хранения данных',
	'engine' => 'Тип',
	'count' => 'Кол-во',
	'chooseStorageEnginesMsg' => 'Выберите систему хранения для таблиц. Не забудьте сделать резервную копию базы данных!',
	'convert' => 'Преобразовать',
	'convertedMsg' => 'Преобразованы таблицы: %s.',
);

==> HostCMS.Free_7.0.tar.gz: modules/benchmark/i18n/ru.php <==
<?php
/**
 * Benchmark.
 *
 * @package HostCMS
 * @subpackage Benchmark
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2021 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Оценка производительности',
	'menu' => 'Производительность',
	'menu_speed' => 'Быстродействие',
	'menu_rate' => 'Оценить производительность',
	'menu_site_speed' => 'Быстродействие сайта',
	'title' => 'Оценка производительности',
	'mbps' => '%s Мбит/с',
	'download_speed' => 'Скорость скачивания',
	'email' => 'Почтовая система',
	'email_val' => '%s сек.',
	'cpu_string' => 'Процессор, строки',
	'cpu_math' => 'Процессор, алгебра',
	'filesystem' => 'Файловая система',
	'bd_change' => 'БД, изменение',
	'bd_read' => 'БД, чтение',
	'bd_write' => 'БД, запись',
	'server' => 'Сервер',
	'etalon' => 'Эталон',
	'benchmark' => 'Общая оценка',
	'check_success' => 'Оценка производительности выполнена',
	'markDeleted_success' => 'Оценка производительности удалена',
	'waiting_time' => 'Ожидание ответа',
	'load_page_time' => 'Загрузка страницы',
	'dns_lookup' => 'Определение DNS',
	'connect_server' => 'Соединение с сервером',
	'start_monitoring' => 'Включить мониторинг быстродействия сайта',
	'reset' => 'Исходный вид',
	'benchmark_day' => 'Быстродействие по дням',
	'benchmark_hour' => 'Быстродействие по часам',

	'cache' => 'Кэширование',
	'cache_description' => 'Кэширует элементы страниц сайта с целью ускорения работы сайта, минимизации использования системных ресурсов в случае большой нагрузки на сервер.',

	'compression' => 'Компрессия страниц',
	'compression_description' => 'Компрессия ускоряет загрузку страниц сайта, сжимает передаваемые посетителям страницы сайта, объединяет Javascript и CSS-файлы.',
	'speedUp' => 'Повышение быстродействия',
	'database' => 'База данных',
	'tableEngines' => 'Типы таблиц в базе данных',
	'tableCharsets' => 'Кодировки таблиц в базе данных',
	'severalEnginesMsg' => 'В базе данных содержатся таблицы разных типов!',
	'severalCharsetsMsg' => 'В базе данных содержатся таблицы в разных кодировках!',
	'changeStorageEnginesTitle' => 'Изменение системы хранения данных',
	'changeStorageCharsetTitle' => 'Изменение кодировки',
	'engine' => 'Тип',
	'count' => 'Кол-во',
	'changeMsg' => 'Не забудьте сделать резервную копию базы данных!',
	'convert' => 'Преобразовать',
	'convertedMsg' => 'Преобразованы таблицы: %s.',
	'add_counter' => 'Автоматически добавить код отслеживания',

	'option_database_table_name' => 'Название таблицы в базе данных',
	'option_database_write_query_count' => 'Количество запросов на запись',
	'option_database_read_query_count' => 'Количество запросов на чтение',
	'option_database_change_query_count' => 'Количество запросов на изменение',
	'option_sample_text' => 'Пример текста',
	'option_files_count' => 'Количество файлов',
	'option_math_count' => 'Количество вычислений',
	'option_string_count' => 'Количество строк',
	'option_benchmark_file_path' => 'Путь к файлу для скачивания',
);
